---
name: code change failed tests report
about: This template is specifically designed for testing major code changes in the
  case of inconsistency in output.
title: "[Failed Tests]"
labels: ''
assignees: ''

---

* datacube-ows branch:
* config file branch or custom:

### Major errors

```
error here
```
**impacted layer**
Please list the link that is returning the error message.

| item no. | layer | url |
| --------- | ----- | --- |
|  1.          | TBA  | link |

### Output differences


| Item no. | layer        | old code link           | new code link  |
|  ------ | ------------- |:-------------|:-----|
| 1.  | TBA   | old link | new link |
